part of ngx_core;

/// Defines the methods and properties of the client application.
class Application {

  /// The application settings.
  final Configuration _configuration;

  /// The current HTML document.
  final dom.HtmlDocument _document;

  /// The service providing access to the meta tags.
  final Meta _meta;

  /// The service providing access to the browser's window.
  final dom.Window _window;

  /// Creates a new configuration service.
  Application(@Inject(envToken) @Optional() String environment, @Inject(APP_ID) this.id, this._configuration, this._document, this._meta, this._window):
    environment = environment ?? const String.fromEnvironment('env', defaultValue: 'development');

  /// The base URL of the remote services.
  Uri get apiUrl => _configuration['apiUrl'] is String ? Uri.tryParse(_configuration['apiUrl']) : null;

  /// Value indicating whether the application is running in debug mode.
  bool get debug => _configuration['debug'] ?? const ['development', 'test'].contains(environment);

  /// The application environment. Defaults to `"development"`.
  final String environment;

  /// Value indicating whether the application shoud use a secure connection.
  bool get forceSsl => _configuration['forceSsl'] ?? false;

  /// A string that uniquely identifies this application.
  final String id;

  /// The language that the document is written in.
  String get language => _document.documentElement.lang;
  set language(String value) => _document.documentElement.lang = value;

  /// The application name. Defaults to `"My Application"`.
  String get name => _meta['application-name'] ?? 'My Application';
  set name(String value) => _meta['application-name'] = value;

  /// Value indicating whether smooth scrolling is supported.
  bool get smoothScrollSupported {
    try { return _document.documentElement.style.scrollBehavior != null; }
    on Exception { return false; }
  }

  /// The version number of the application package. Defaults to `"1.0"`.
  String get version => _configuration['version'] ?? const String.fromEnvironment('version', defaultValue: '1.0');

  /// Forces the currently requested URL to use a secure channel (e.g. HTTPS).
  void useSecureConnection() {
    if (Uri.base.scheme != 'https') _window.location.assign(Uri.base.replace(scheme: 'https').toString());
  }
}
